# Security

We're trying to make WeLearn as secure as possible. If you discover a security issue, please bring it to our attention right away. We take security seriously and will do our best to address the issue promptly.


## Reporting Security Issues

**Please do not report security vulnerabilities through public GitHub issues.**
Instead, email us at [welearn@learningplanetinstitute.org](mailto:welearn@learningplanetinstitute.org), put **[SECURITY]** in the subject line.

Please include the requested information listed below (as much as you can provide) to help us better understand the nature and scope of the possible issue:

  * Type of issue (e.g. buffer overflow, SQL injection, cross-site scripting, etc.)
  * Full paths of source file(s) related to the manifestation of the issue
  * The location of the affected source code (tag/branch/commit or direct URL)
  * Any special configuration required to reproduce the issue
  * Step-by-step instructions to reproduce the issue
  * Proof-of-concept or exploit code (if possible)
  * Impact of the issue, including how an attacker might exploit the issue

## Preferred Languages

We prefer all communications to be in English or in French.

_Freely inspired from [Microsoft SECURITY.md](https://github.com/microsoft/.github/blob/main/SECURITY.md)_